# Configuration

The default configuration files required for whatsthedamage are placed in `src/whatsthedamage/config`.

The prominent examples are:
 - config.yml.default
 - exclusions.json

The `gunicorn_conf.py` is for Gunicorn, it is not necessarily required of the package to operate.
